@@ -49,9 +49,6 @@ def ScientificNotation(num):
                 revs += 1
                 return str(num) + "x10^" + str(revs)
             elif num <= 0:
-                num /= 10
+                num /= -10
                 revs == 1
-        if num > 0:
-            return str(-num) + "x10^" + str(revs)
-        elif num < 0:
-            return str(num) + "x10^" + str(revs)
\ No newline at end of file
+            return str(-num) + "x10^" + str(revs)
\ No newline at end of file
